@@ -26,9 +26,8 @@ reddit_parser.add_argument(
 
 reddit_parser.add_argument(
     "-p",
-    # "--pwd",
     "--password",
-    metavar="pwd",
+    metavar="password",
     nargs=1,
     action="store",
     type=str,
@@ -48,3 +47,18 @@ reddit_parser.add_argument(
     action="store_true",
     help="Manually configure reddit credentials for this user agent.",
 )
+
+reddit_parser.add_argument(
+    "--csv",
+    metavar="csv_file",
+    nargs=1,
+    action="store",
+    type=str,
+    help="specify csv file to parse and archive",
+)
+
+reddit_parser.add_argument(
+    "--interact",
+    action="store_true",
+    help="interact with database and reddit API",
+)
